@@ -1,4 +1,4 @@
 # Share the fixtures for the tasks tests
 
 # noinspection PyUnresolvedReferences
-from tests.adapter.dbt_adapter.conftest import dbt_test_helper
+from tests.adapter.dbt_adapter.conftest import dbt_test_helper  # noqa: F401
